@@ -7,6 +7,7 @@ Description:
 '''
 
 import enchant as e
+import confopy.config as C
 
 ENCHANT_LANG_MAP = {
       u"de": u"de_DE"
@@ -26,12 +27,22 @@ def list_languages():
 class SpellChecker(object):
     """Wrapper for PyEnchant.
     """
-    def __init__(self, lang=u"de"):
+    def __init__(self, lang=C.DEFAULT_LANG):
+        """Initializes a spellchecker with a given language.
+        Args:
+            lang: Language code, e.g. u"de" or u"en", for the spellchecker.
+        """
         super(SpellChecker, self).__init__()
         pyenchant_lang = ENCHANT_LANG_MAP.get(lang, u"de_DE")
         self._enchant_dict = e.Dict(pyenchant_lang)
 
     def check(self, word):
+        """Checks a given word.
+        Args:
+            word: A unicode string.
+        Return:
+            Boolean. True if word is spelled correctly.
+        """
         return self._enchant_dict.check(word)
 
     def suggest(self, word):
