@@ -7,6 +7,7 @@ Description:
 '''
 
 from confopy.analysis import Report, Analyzer, mean_stdev
+from confopy.analysis.rule import eval_doc
 
 
 METRIC_NAMES = [u"wordlength", u"spellcheck", u"lexicon", u"sentlength", u"personalstyle", u"impersonalstyle", u"passiveconstructs", u"simplepres", u"adverbmodifier", u"deadverbs", u"fillers", u"examplecount", u"sentlengthvar"]
@@ -176,6 +177,18 @@ class DocumentReport(Report):
         doc = docs[0]
         for metric_ID in sorted((_METRIC_EXPECTATIONS.keys())):
             output.append(self._execute_metric(metric_ID, doc))
+        output.append(u"")
+        output.append(u"## Regeln")
+        output.append(u"")
+        rule_IDs = [u"introduction", u"subsections", u"floatreference"]
+        A = Analyzer.instance()
+        rules = [A.get(rule=ID) for ID in rule_IDs if A.get(rule=ID) is not None]
+        rule_messages = eval_doc(doc, rules)
+        if len(rule_messages) == 0:
+            output.append(u"Es liegen keine Regelverletzungen vor!")
+        else:
+            for m in rule_messages:
+                output.append(m)
         return u"\n".join(output)
 
     def _execute_metric(self, metric_ID, node):
